@@ -2,7 +2,7 @@
 # the problem with this method is that the panel.fun do not know the correct 
 # subject factor because it had not subdivide in therms of the | in the formula 
 # so the we have to include coplotnew() to rectify this 
-par.plot<- function(formula = NULL,
+par.plot1<- function(formula = NULL,
                        data = NULL,
                      subjects = NULL,
                       color = TRUE,
@@ -467,7 +467,9 @@ par.plot<- function(formula = NULL,
 #----------------------------------------------------------------------
 # here is the main function    
 #----------------------------------------------------------------------
-if (!is.null(data)) {attach(data) ; on.exit(detach(data))} 
+#if (!is.null(data)) {attach(data) ; on.exit(detach(data))} 
+browser()
+
 if (is.null(subjects)) stop("the subjects factor is not set")  
 if (!is.factor(subjects)) stop("the subjects argument should be a factor")
    subjects <- factor(as.integer(subjects))
